@@ -41,6 +41,11 @@ try:
 except ImportError:
     Figure = None
 
+try:
+    import gnupg
+except ImportError:
+    gnupg = None
+
 try:
     from src.lib.gpg import genkey
 except ImportError:
@@ -613,6 +618,9 @@ class MainWindowEventHandlers(EventMixin):
 
         """
 
+        if gnupg is None:
+            return
+
         if genkey is None:
             # gnupg is not present
             self.interfaces.display_warning(
