@@ -423,7 +423,7 @@ class ImageComboBox(wx.combo.OwnerDrawnComboBox):
         # Otherwise, draw every other background with
         # different color.
 
-        bg_color = get_color(wx.SYS_COLOUR_BACKGROUND)
+        bg_color = get_color(config["label_color"])
         dc.SetBrush(wx.Brush(bg_color))
         dc.SetPen(wx.Pen(bg_color))
         dc.DrawRectangleRect(rect)
@@ -600,11 +600,14 @@ class FontChoiceCombobox(ImageComboBox):
         height = layout.get_pixel_extents()[1][3]
 
         y_adjust = int((rect.height - height) / 2.0)
+        context.save()
         context.translate(rect.x + 3, rect.y + y_adjust)
 
         pangocairo_context.update_layout(layout)
         pangocairo_context.show_layout(layout)
 
+        context.restore()
+
 # end of class FontChoiceCombobox
 
 
